@@ -210,7 +210,7 @@ int rfc3676parser(rfc3676_parser_t handle,
 		  size_t txt_cnt)
 {
 	if (handle->errflag)
-		return handle->errflag; /* Error occured previously */
+		return handle->errflag; /* Error occurred previously */
 
 	/* Convert to unicode and invoke parse_unicode() */
 
@@ -249,15 +249,24 @@ static int parse_unicode(const char *ucs4, size_t nbytes, void *arg)
 
 		/* Keep feeding it to the current handler */
 
-		while (handle->errflag == 0 && cnt)
-		{
-			size_t n=(*handle->line_handler)(handle, p, cnt);
+		rfc3676parser_unicode(handle, p, cnt);
+	}
 
-			if (handle->errflag == 0)
-			{
-				cnt -= n;
-				p += n;
-			}
+	return handle->errflag;
+}
+
+int rfc3676parser_unicode(rfc3676_parser_t handle,
+			  const char32_t *p,
+			  size_t cnt)
+{
+	while (handle->errflag == 0 && cnt)
+	{
+		size_t n=(*handle->line_handler)(handle, p, cnt);
+
+		if (handle->errflag == 0)
+		{
+			cnt -= n;
+			p += n;
 		}
 	}
 
@@ -748,8 +757,7 @@ static void nonflowed_line_begin(rfc3676_parser_t handle)
 
 	if (handle->lb)
 		unicode_lbc_set_opts(handle->lb,
-				     UNICODE_LB_OPT_PRBREAK
-				     | UNICODE_LB_OPT_SYBREAK);
+				     UNICODE_LB_OPT_PRBREAK);
 
 	unicode_buf_clear(&handle->nonflowed_line);
 	unicode_buf_clear(&handle->nonflowed_next_word);
