@@ -13,9 +13,7 @@
 
 #include	"rfc822hdr.h"
 #include	"rfc2047.h"
-#if LIBIDN
 #include <idn2.h>
-#endif
 
 
 #define	RFC2047_ENCODE_FOLDLENGTH	76
@@ -29,7 +27,8 @@ static char *a_rfc2047_encode_str(const char *str, const char *charset,
 
 static void rfc2047_encode_header_do(const struct rfc822a *a,
 				     const char *charset,
-				     void (*print_func)(char, void *),
+				     void (*print_func)(const char *, size_t,
+							void *),
 				     void (*print_separator)(const char *,
 							     void *), void *ptr)
 {
@@ -43,7 +42,6 @@ static char *rfc822_encode_domain_int(const char *pfix,
 {
 	char *q;
 
-#if LIBIDN
 	int err;
 	char *p;
 	size_t s=strlen(domain)+16;
@@ -68,14 +66,6 @@ static char *rfc822_encode_domain_int(const char *pfix,
 		errno=EINVAL;
 		return NULL;
 	}
-#else
-	char *p;
-
-	p=strdup(domain);
-
-	if (!p)
-		return NULL;
-#endif
 
 	q=malloc(strlen(p)+pfix_len+1);
 
@@ -180,9 +170,9 @@ static char *a_rfc2047_encode_str(const char *str, const char *charset,
 	return rfc2047_encode_str(str, charset, rfc2047_qp_allow_word);
 }
 
-static void count(char c, void *p);
+static void count(const char *c, size_t l, void *p);
 static void counts2(const char *c, void *p);
-static void save(char c, void *p);
+static void save(const char *c, size_t l, void *p);
 static void saves2(const char *c, void *p);
 
 char *rfc2047_encode_header_addr(const struct rfc822a *a,
@@ -227,37 +217,41 @@ char *rfc2047_encode_header_tobuf(const char *name, /* Header name */
 	return rfc2047_encode_str(header, charset, rfc2047_qp_allow_word);
 }
 
-static void count(char c, void *p)
+static void count(const char *c, size_t l, void *p)
 {
-	++*(size_t *)p;
+	*(size_t *)p += l;
 }
 
 static void counts2(const char *c, void *p)
 {
 	if (*c == ',')
-		count(*c++, p);
+	{
+		count(c, 1, p);
+		++c;
+	}
 
-	count('\n', p);
-	count(' ', p);
+	count("\n ", 2, p);
 
-	while (*c)	count(*c++, p);
+	count(c, strlen(c), p);
 }
 
-static void save(char c, void *p)
+static void save(const char *c, size_t l, void *p)
 {
-	**(char **)p=c;
-	++*(char **)p;
+	memcpy(*(char **)p, c, l);
+	*(char **)p += l;
 }
 
 static void saves2(const char *c, void *p)
 {
 	if (*c == ',')
-		save(*c++, p);
+	{
+		save(c, 1, p);
+		++c;
+	}
 
-	save('\n', p);
-	save(' ', p);
+	save("\n ", 2, p);
 
-	while (*c)	save(*c++, p);
+	save(c, strlen(c), p);
 }
 
 static int encodebase64(const char *ptr, size_t len, const char *charset,
@@ -595,12 +589,12 @@ static int do_encode_words(const char32_t *uc,
 /*
 ** RFC2047-encoding pass.
 */
-static int rfc2047_encode_callback(const char32_t *uc,
-				   size_t ucsize,
-				   const char *charset,
-				   int (*qp_allow)(char),
-				   int (*func)(const char *, size_t, void *),
-				   void *arg)
+int rfc2047_encode_callback(const char32_t *uc,
+			    size_t ucsize,
+			    const char *charset,
+			    int (*qp_allow)(char),
+			    int (*func)(const char *, size_t, void *),
+			    void *arg)
 {
 	int	rc;
 	size_t	i;
